face: Making class variables names more consistent

Change-Id: I105ee77623c1f3f5d477ac058b25081c57e57e21
diff --git a/src/face.hpp b/src/face.hpp
index b617e42..6aac1e0 100644
--- a/src/face.hpp
+++ b/src/face.hpp
@@ -192,7 +192,7 @@
   shutdown();
 
   shared_ptr<boost::asio::io_service> 
-  ioService() { return ioService_; }
+  ioService() { return m_ioService; }
 
 private:
   void
@@ -232,7 +232,7 @@
   getEntryIndexForExpressedInterest(const Name& name);
   
   /**
    * Find the first entry from the registeredPrefixTable_ where the entry prefix is the longest that matches name.
    * @param name The name to find the PrefixEntry for (from the incoming interest packet).
    * @return A pointer to the entry, or 0 if not found.
    */
@@ -244,16 +244,16 @@
   checkPitExpire();
   
 private:
-  shared_ptr<boost::asio::io_service> ioService_;
-  shared_ptr<boost::asio::io_service::work> ioServiceWork_; // needed if thread needs to be preserved
-  shared_ptr<boost::asio::deadline_timer> pitTimeoutCheckTimer_;
-  bool pitTimeoutCheckTimerActive_;
-  shared_ptr<boost::asio::deadline_timer> processEventsTimeoutTimer_;
+  shared_ptr<boost::asio::io_service> m_ioService;
+  shared_ptr<boost::asio::io_service::work> m_ioServiceWork; // needed if thread needs to be preserved
+  shared_ptr<boost::asio::deadline_timer> m_pitTimeoutCheckTimer;
+  bool m_pitTimeoutCheckTimerActive;
+  shared_ptr<boost::asio::deadline_timer> m_processEventsTimeoutTimer;
   
-  shared_ptr<Transport> transport_;
+  shared_ptr<Transport> m_transport;
 
-  PendingInterestTable pendingInterestTable_;
-  RegisteredPrefixTable registeredPrefixTable_;
+  PendingInterestTable m_pendingInterestTable;
+  RegisteredPrefixTable m_registeredPrefixTable;
 
   shared_ptr<Controller> m_fwController;
 };
@@ -232,7 +232,7 @@
   
   /**
-   * Find the first entry from the registeredPrefixTable_ where the entry prefix is the longest that matches name.
+   * Find the first entry from the m_registeredPrefixTable where the entry prefix is the longest that matches name.
    * @param name The name to find the PrefixEntry for (from the incoming interest packet).
    * @return A pointer to the entry, or 0 if not found.